import QtQml.Base
import QtQuick
import QtQuick.Layouts

import Core
import I18n
import Dialog

import "../core"
import "../widgets"

BaseForm {
    id: root
    Style.class: "customerAddressForm"

    allowFloatKeyboard: false

    property var action: DialogState.actions[Context.id.value]
    property int selectedType: action.types[0]

    onSelectedTypeChanged: () => inputField.text = ""

    onActivated: () => inputField.forceActiveFocus()

    Context.inputSources: InputSources.Scanner

    function accept() {
        if (!inputField.acceptableInput)
            return

        action.address = inputField.text
        removeContext()
    }

    function reject() {
        action.address = ""
        removeContext()
    }

    contentItem: ColumnLayout {
        spacing: 40

        SGroupBox {
            Style.class: "customerAddressMain"
            leftPadding: 173
            rightPadding: 173
            topPadding: 280

            contentItem: ColumnLayout {
                spacing: 60

                SLabel {
                    Style.class: "customerAddressTitle"
                    horizontalAlignment: SLabel.AlignHCenter
                    wrapMode: SLabel.WordWrap
                    Tr { code: "addressTitle" }
                    Layout.fillWidth: true
                }

                ColumnLayout {
                    spacing: 40

                    SLabel {
                        Style.class: "customerAddressSelectType"
                        horizontalAlignment: SLabel.AlignHCenter
                        wrapMode: SLabel.WordWrap
                        Tr { fallback: "addressSelectType" }
                        Layout.fillWidth: true
                    }

                    RowLayout {
                        spacing: 40
                        visible: action.types.length > 1

                        ActionButton {
                            Style.class: "customerAddressType"
                            visible: root.action.types.find((type) => type == DialogTypes.CustomerAddressType.Email) != null
                            enabled: selectedType != DialogTypes.CustomerAddressType.Email

                            onClicked: () => root.selectedType = DialogTypes.CustomerAddressType.Email

                            Tr { code: "addressEmail" }

                            Layout.fillWidth: true
                            Layout.preferredHeight: 100
                        }

                        ActionButton {
                            Style.class: "customerAddressType"
                            visible: root.action.types.find((type) => type == DialogTypes.CustomerAddressType.Sms) != null
                            enabled: selectedType != DialogTypes.CustomerAddressType.Sms

                            onClicked: () => root.selectedType = DialogTypes.CustomerAddressType.Sms

                            Tr { code: "addressSms" }

                            Layout.fillWidth: true
                            Layout.preferredHeight: 100
                        }

                        Layout.fillWidth: true
                    }
                }

                SLabel {
                    Style.class: "customerAddressHint"
                    horizontalAlignment: SLabel.AlignHCenter
                    wrapMode: SLabel.WordWrap

                    Tr {
                        code: {
                            switch (selectedType) {
                            case DialogTypes.CustomerAddressType.Email: return "addressEmailMsg";
                            case DialogTypes.CustomerAddressType.Sms: return "addressSmsMsg";
                            default: return "";
                            }
                        }
                    }

                    Layout.fillWidth: true
                }

                SGroupBox {
                    Style.class: "customerAddressInputField"

                    contentItem: FocusScope {
                        focus: true
                        implicitHeight: inputField.implicitHeight

                        STextEdit {
                            id: inputField
                            anchors.fill: parent

                            horizontalAlignment: Qt.AlignHCenter
                            focus: true

                            inputMethodHints: {
                                switch (selectedType) {
                                case DialogTypes.CustomerAddressType.Sms: return Qt.ImhDigitsOnly;
                                case DialogTypes.CustomerAddressType.Email: return Qt.ImhNoAutoUppercase | Qt.ImhEmailCharactersOnly;
                                }
                            }

                            RegularExpressionValidator {
                                id: emailValidator
                                regularExpression: /^[a-zA-Z0-9_.+-]+@[a-zA-Zа-яА-ЯЁё0-9-]+\.[a-zA-Zа-яА-ЯЁё0-9-.]{2,}$/
                            }

                            validator: {
                                switch (selectedType) {
                                case DialogTypes.CustomerAddressType.Email: return emailValidator
                                default: return null
                                }
                            }
                            inputMask: {
                                switch (selectedType) {
                                case DialogTypes.CustomerAddressType.Sms: return "+7(999)999-99-99"
                                default: return "";
                                }
                            }

                            Component.onCompleted: () => {
                                this.text = root.action.defaultAddress
                                this.forceActiveFocus()
                            }
                        }
                    }

                    Layout.fillWidth: true
                }

                Space { Layout.fillHeight: true }
            }

            Layout.fillWidth: true
            Layout.fillHeight: true
        }

        SGroupBox {
            Style.class: "customerAddressKeyboard"
            property bool isEmail: selectedType == DialogTypes.CustomerAddressType.Email
            contentItem: InlineKeyboard {
                layoutType: parent.isEmail ? "email" : "dialpad"
                defaultLocale: "en_US"
            }

            property real hPadding: isEmail ? 35 : 172
            leftPadding: hPadding
            rightPadding: hPadding

            Layout.fillWidth: true
            Layout.preferredHeight: isEmail ? 534 : 450
        }

        RowLayout {
            spacing: 40

            ActionButton {
                Style.class: "customerAddressCancel"
                implicitWidth: 1

                Tr { tr: root.action.cancelButton; fallback: "addressCancel" }

                onClicked: () => root.reject()

                Layout.fillWidth: true
                Layout.preferredHeight: 110
            }

            ActionButton {
                Style.class: "customerAddressApply"
                implicitWidth: 1
                enabled: inputField.acceptableInput

                Tr { tr: root.action.okButton; fallback: "addressAccept" }

                onClicked: () => root.accept()

                Layout.fillWidth: true
                Layout.preferredHeight: 110
            }

            Layout.fillWidth: true
        }
    }
}
